@@ -9,6 +9,10 @@ WEBPACK_CONFIG_PATH = "webpack.dev.config.js"
 
 SESSION_COOKIE_DOMAIN = ".{{ LMS_HOST|common_domain(CMS_HOST) }}"
 
+LMS_BASE = "{{ LMS_HOST}}:8000"
+LMS_ROOT_URL = "http://{}".format(LMS_BASE)
+LMS_INTERNAL_ROOT_URL = LMS_ROOT_URL
+SITE_NAME = LMS_BASE
 CMS_BASE = "{{ CMS_HOST}}:8001"
 CMS_ROOT_URL = "http://{}".format(CMS_BASE)
 LOGIN_REDIRECT_WHITELIST.append(CMS_BASE)
